:
# telnet-banner.sh
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1992, 1993, 1994, 1995, 1996, 1997, 1998
# with input from Casper Dik, and Alec Muffet.
# Solaris inetd.sh was used as a skeleton for this module.
# Modified by Derek Werthmuller for FreeBSD.
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.

# setup
TITANHOME=`pwd`
PATH=/usr/ucb:/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
OS=`uname -r`
HOST=`uname -n`
DATE=`/bin/date +%Y%m%d%H%M`
SAVEFILES='/etc/hosts.allow'

. misc_functions.sh

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

Intro() {

cat << EOF

 $MYNAME - This program copies /etc/hosts.allow to /etc/hosts.allow.ORIG
 and modifies the runtime /etc/hosts.allow so that the following
 tcp services will present a pre-login banner. 

 tcp banner  services include:

	telnetd ftpd rlogind

 NOTE: Important -> this overrides existing host.allow filters!
	To place your access filters in this script change filter entry.
 Should you need to change this vi this script and modify the
 \$ServiceList variable to include/exclude as you wish....
 
EOF

}

ServiceList="telnetd ftpd rlogind"
filter="ALL"

Fix() {

 if [ -f /etc/hosts.allow  ]; then
  t_echo 2 " File /etc/hosts.allow exists - Backing up to hosts.allow.${DATE}"
  cp /etc/hosts.allow /etc/hosts.allow.${DATE}
  if [ ! -d /etc/banners ]; then
    t_echo 2 " /etc/banners doesn't exist Creating.."
    mkdir /etc/banners
   
    cp ./lib/issue  /etc/banners/prototype
    cp ./lib/Banners.Makefile  /etc/banners/Makefile
    cd /etc/banners
	make all
    cd $TITANHOME 
  fi
 
 else
  t_echo 1 "        Could not locate /etc/hosts.allow - Exiting.."
  t_echo 1 "	    See man pages for hosts_options(5) to configure"
  t_echo 1 "	    /etc/hosts.allow and tcpwrappers."
  exit 1
 fi

 t_echo 0 " Making changes to /etc/hosts.allow to configure banners."
 t_echo 0 " The original version is saved as /etc/hosts.allow.${DATE}"

 for SERVC in $ServiceList
  do
 ed - /etc/hosts.allow <<-!
/#
a
.
a
$SERVC : $filter : banners /etc/banners
.
w
q
!

 done
 t_echo 2 " Changing /etc/hosts.allow to mode 644 ..."
 chmod 644 /etc/hosts.allow

}


Check() {

 if [ -f /etc/hosts.allow  -a -d /etc/banners ]; then
  t_echo 2 " File /etc/hosts.allow exists - Checking..."
 else
  t_echo 1 "ERROR     could not find /etc/hosts.allow or /etc/banners"
  exit 1
 fi

 for SERVC in $ServiceList
  do
grep "^${SERVC} : ALL : banners /etc/banners/${SERVC}" /etc/hosts.allow >/dev/null 2>&- 

    if [ $? -eq 0 ]; then
    t_echo 0 "        $SERVC has no banner - FAILS CHECK"
    else
    t_echo 2 "        $SERVC has a banner - Passes CHECK"
    fi

 done

}

action=$1
        case ${action} in
	-[Ii]*)
	Intro
	;;
         -[Ff]*)
        Fix
        ;;
        -[Vv]*)
        Check
        ;;
        *)
        t_echo 1 " ERROR - Invalid arg $action"
        t_echo 1 " ERROR - Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
        ;;
        esac

