:
# cronset.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.1.4 Sep 12 09:21:02 PDT 1999
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#
#This module donated by Mitko Stoyanov, August 1999
 
 
TITANHOME=`pwd`
MYNAME=`basename $0`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/default/cron /etc/cron.d/logchecker'
RUNDATE=`/usr/bin/date +%Y%m%d%H%M`
OS=`uname -r`

CRONLOGDIR="/var/cron"
CRONDFILE="/etc/default/cron"
CRONLCHK="/etc/cron.d/logchecker"


# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh
 
Intro() {
cat << EOF_INTRO
$MYNAME : This script checks/puts CRONLOG=YES in /etc/default/cron,
It also changes the permissions of /var/cron so that the users cannot
peek into the contents of the cron log files, and modifies /etc/cron.d/logchecker
to rotate the log files at 2MB file size.

EOF_INTRO
}

Check() {

#Check whether cron logging is enabled. Take no chances, there
#must be exactly ONE CRONLOG= line which must be CRONLOG=YES

   if [ -r "$CRONDFILE" ] && \
      [ "`grep -cs '^CRONLOG=YES' $CRONDFILE`" -eq 1 ] && \
      [ "`grep -cs '^[^#]*CRONLOG=' $CRONDFILE`" -eq 1 ];then 
       t_echo 1 "   CRONLOG entry found - PASSES CHECK "
   else
      t_echo 0 "  CRONLOG entry not found or misconfigured - FAILS CHECK" 
   fi

#Check the perms of the cron log dir

   if [ -d "$CRONLOGDIR" ] && \
      ls -dl $CRONLOGDIR | grep -s "^drwx------" > /dev/null 2>&1
      then
       t_echo 1 "   $CRONLOGDIR permissions - PASSES CHECK " 
      else
       t_echo 0 "   $CRONLOGDIR permissions - FAILS CHECK " 
      fi

#Check whether the cron log files will be rotated when exceeding 2MB,
#one can find sometime sites with log files > 100MB

  if [ -r "$CRONLCHK" ] &&  grep "LIMIT=4096" $CRONLCHK > /dev/null 2>&1 ; 
      then
       t_echo 1 "   $CRONLCHK LIMIT - PASSES CHECK "
      else
       t_echo 0 "   $CRONLCHK LIMIT - FAILS CHECK "
      fi   

}


Fix() {

   if [ -r "$CRONDFILE" ] && \
      [ "`grep -cs '^CRONLOG=YES' $CRONDFILE`" -eq 1 ] && \
      [ "`grep -cs '^[^#]*CRONLOG=' $CRONDFILE`" -eq 1 ];then 
       t_echo 1 "   CRONLOG entry found : PASSES CHECK "
   else
      t_echo 0 "  CRONLOG entry not found or misconfigured - FAILS CHECK" 
      t_echo 2 "  Fixing $CRONDFILE now...." 
        if [ ! -f "$CRONDFILE" ];then
            touch "$CRONDFILE" && chmod 444 "$CRONDFILE" \
            && chown root "$CRONDFILE" &&  chgrp sys "$CRONDFILE"
        else
        cp -p "$CRONDFILE" $CRONDFILE.${RUNDATE}
        fi
	ed - "$CRONDFILE" <<- __INPUT__ 
	g/^[^#]*CRONLOG=/d
	a
	CRONLOG=YES
	.
	w
	q
	__INPUT__
      if [ "$?" -ne 0 ];then
        t_echo 1 "  Fixing $CRONDFILE FAILED - ERROR check the file" 
        exit 1
      fi
   fi


#Check the perms of the cron log dir

   if [ -d "$CRONLOGDIR" ] && \
      ls -dl $CRONLOGDIR | grep -s "^drwx------" > /dev/null 2>&1
      then
       t_echo 1 "   $CRONLOGDIR permissions - PASSES CHECK " 
      else
       t_echo 0 "   $CRONLOGDIR permissions - FAILS CHECK " 
       t_echo 2 "   Fixing the $CRONLOGDIR permissions ... " 
       if [ -d "$CRONLOGDIR" ]; then :
       else
         mkdir -p /var/cron
       fi
         chmod  700 /var/cron && chown root /var/cron \
         && chgrp sys /var/cron
   fi

#Check whether the cron log files will be rotated when exceeding 2MB,
#one can find sometime sites with log files > 100MB

  if [ -r "$CRONLCHK" ] &&  grep "LIMIT=4096" $CRONLCHK > /dev/null 2>&1 ; 
      then
       t_echo 1 "   $CRONLCHK LIMIT - PASSES CHECK "
      else
      t_echo 0 "   $CRONLCHK LIMIT - FAILS CHECK "
      t_echo 2 "  Fixing $CRONLCHK now...." 

      if [ -r "$CRONLCHK" ];then
      cp -p "$CRONLCHK" "$CRONLCHK".${DATE} && \
	ed "$CRONLCHK" <<- __INPUT__ 
	g/^LIMIT=\`ulimit\`/s/LIMIT=\`ulimit\`/LIMIT=4096/
	.
	w
	q
	__INPUT__
         if [ "$?" -ne 0 ];then
              t_echo 1 "   $CRONLCHK LIMIT - ERROR fix failed "
         fi   
      else
        t_echo 1 "  $CRONLCHK missing! " 
      fi
   fi
}

 
action=$1
case $action in
 -[Ff]*)
Fix
;;
 -[Vv]*)
Check
;;
 -[Ii]*)
Intro
;;
 
*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
;;
esac

