:
# inetd.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# revision 3.0.1 Matt  Thu Oct  8 13:07:10 PDT 1998
# revision 3.1.1 Brad  Tue May 25 09:17:59 PDT 1999
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
OS=`uname -r`
HOST=`uname -n`
DATE=`/bin/date +%Y%m%d%H%M`
SAVEFILES='/etc/inetd.conf /etc/inet/inetd.conf'

. misc_functions.sh

case $OS in
  5*)
   INET=/etc/inet/inetd.conf
  ;;
  4*)
   INET=/etc/inetd.conf
  ;;
 *)
   t_echo 1 "       No valid OS for $0" 
   exit 1
;;
esac

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

Intro() {

cat << EOF

 $MYNAME - This program moves /etc/inetd.conf OR /etc/inet/inetd.conf
 to inetd.confg.ORIG.$DATE and modifies the runtim inetd.conf such
 that the insecure or chatty daemons are turned off.

 Chatty or insecure services include:

  name  exec  comsat  talk  uucp  smtp  tftp  finger
  systat  netstat  rquotad  rusersd  sprayd  walld
  rexd  shell  login  exec  comsat  time echo discard
  daytime  chargen  100087(sadmind) rwalld  rstatd
  100068(cmsd)  100083(ttdbserverd) 100221(kcms)
  fs ufsd as well as the new SUNWvts remote diag tool

 Should you need to change this vi this script and modify the
 \$ChatList variable to include/exclude as you wish....
 
EOF

}

ChatList="name exec comsat talk uucp smtp tftp finger systat netstat rquotad rusersd sprayd walld rexd shell login exec comsat time echo discard daytime chargen 100087 rwalld rstatd 100068 100083 100221 fs ufsd 100232 100235 printer 536870916"


Fix() {

 if [ -f ${INET} -a -s ${INET} ]; then
  t_echo 2 " File $INET exists - Backing up to ${INET}.ORIG.${DATE}"
  cp -p ${INET} ${INET}.ORIG.${DATE}
 else
  t_echo 1 "        Could not locate ${INET} - ERROR"
  exit 1
 fi

 t_echo 2 " Making changes to $INET to close all insecure/chatty services..."
 t_echo 2 " Note: Manually edit inetd if you use non-standard services."
 t_echo 2 " The original version is saved as ${INET}.${DATE}"

 for SERVC in $ChatList
  do
 ed - $INET << EOEF 
g/^$SERVC/s/^$SERVC/#\ $SERVC/g
.
w
q
EOEF
 done
 t_echo 2 " Changing ${INET} to mode 644 ..."
 chmod 644 ${INET}

}


Check() {

 if [ -f ${INET} -a -s ${INET} ]; then
  t_echo 2 " File $INET exists - Checking..."
 else
  t_echo 1 "       ERROR - Could not locate ${INET} "
  exit 1
 fi

 for SERVC in $ChatList
  do
    grep "^${SERVC}" ${INET} >/dev/null 2>&-

    if [ $? -eq 0 ]; then
    t_echo 0 "        $SERVC Open - FAILS CHECK"
    else
    t_echo 1 "        $SERVC Closed - PASSES CHECK"
    fi

 done

}

action=$1
        case ${action} in
	-[Ii]*)
	Intro
	;;
         -[Ff]*)
        Fix
        ;;
        -[Vv]*)
        Check
        ;;
        *)
        t_echo 1 " ERROR - Invalid arg $action"
        t_echo 1 " ERROR - Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
        ;;
        esac

