:
# powerd.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0 solaris 8 changed /etc/default/power to /etc/power.conf
# 2001-04-26 JKR I fixed greps, and changed check a little
# bpowell 03/04/02 added in stripping the suid bit from /sbin/pmconfig
# since its now only runable by root, why leave the binary suid?
# version 4.0. beta3

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 
#
# Modified by Kyle Haugsness - this script was previously broken because
# of several bugs.  Here's a list of changes:
#  - The script didn't seem to be changing the destination file if it found
#      a problem.  This is fixed now.
#  - The script no longer assumes that the values in the file will be set
#      to "console-owner".  If any value other than "-" is received, it'll
#      take action and correct or report it.
#  - The script wasn't checking the CPRCHANGEPERM parameter in the script.
#      Seems like we should set this variable, too.
#  - The script now correctly handles commented entries in the file.
#  - The script puts a message above the entry modified stating which
#      module changed the file.
#

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/default/power /etc/power.conf'
OS=`uname -r`

 . misc_functions.sh
 
 case "`uname -r`" in
 5.[789]*) ;;
 *)
         t_echo 1 "$MYNAME ERROR - This script is Only needed on Solaris 2.7 and newer "
         exit 1;;
 esac


# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

Intro () {

cat << EOF

  $MYNAME - Script to change power management to be only runable by root

EOF

}

 Fix() {
 
 if [ -f /etc/default/power ] ; then
 
 
 	# Modified - we just need to test the count of lines from grep
 	# This part of the module was previously broken
 	if [ `grep -cs "^[^#]*PMCHANGEPERM=-" /etc/default/power` -ge 1 ]; then
           # Add a log entry
           t_echo 1 "         Power management (PM) is set to only be runnable by  root  - PASSES CHECK"

	else

           t_echo 2 "         Power management (PM) being set to be run by root only  "
	   # Backup the file and preserve file permissions
	   cp -p /etc/default/power /etc/default/power.ORIG.$DATE

	   # Now make changes to the file
		ed - /etc/default/power <<- !
		g/^[^#]*PMCHANGEPERM=.*/s//PMCHANGEPERM=-/
		.
		g/^#*PMCHANGEPERM=.*/s//PMCHANGEPERM=-/
		^
		a
		# Modified by Titan 4.0 - "powerd2.8.sh" module
		.
		w
		q
		!

	fi

	# Added a check for CPRCHANGEPERM
	if [ `grep -cs "^[^#]*CPRCHANGEPERM=-" /etc/default/power` -ge 1 ]; then
          # Add a log entry
           t_echo 1 "         Power management (CPR) is set to only be runnable by  root  - PASSES CHECK"

	else

           t_echo 2 "         Power management (CPR) being set to be run by root only  "
	   # Backup the file and preserve file permissions
	   cp -p /etc/default/power /etc/default/power.ORIG.$DATE

	   # Now make changes to the file

		ed - /etc/default/power <<- !
		g/^[^#]*CPRCHANGEPERM=.*/s//CPRCHANGEPERM=-/
		.
		g/^#*CPRCHANGEPERM=.*/s//CPRCHANGEPERM=-/
		^
		a
		# Modified by Titan 4.0 - "powerd2.8.sh" module
		.
		w
		q
		!

	fi
fi

if [ ! -f /etc/default/power ] ; then
t_echo 1 "         Power management is not configured or installed"
fi

if [ -f /etc/power.conf ] ; then
	mv /etc/power.conf /etc/power.conf.ORIG.$DATE
fi

if [ -f /etc/rc2.d/S85power ] ; then
	mv /etc/rc2.d/S85power /etc/rc2.d/s85power
	/usr/sbin/pmconfig -r
fi

if [ -f /usr/sbin/pmconfig ] ; then
	chmod 0500 /usr/sbin/pmconfig
fi

}

Check() {

if [ -f /etc/default/power ] ; then
	if [ `grep -cs "^[^#]*PMCHANGEPERM=-" /etc/default/power` -ge 1 -a \
	 `grep -cs "^[^#]*CPRCHANGEPERM=-" /etc/default/power` -ge 1 ]; then
           t_echo 1 "         Power management is set to only be runnable by  root  - PASSES CHECK"
	else
           t_echo 0 "        Power management not set to be run by root  - FAILS CHECK "
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (powerd.sh -f) See also nuke-powerd.sh. For those systems"
        t_echo 3 "which use powerd powerd should be configured to only allow power management to"
        t_echo 3 "be set by "root" Titan enforces this by changing: "
        t_echo 3 "/etc/default/sys-suspend changing the PERMS line "
        t_echo 3 "to "
        t_echo 3 "  "
        t_echo 3 "    PERMS=- "
        t_echo 3 " "
        t_echo 3 "======================================================================== "

	fi
fi

if [ ! -f /etc/default/power ] ; then
 t_echo 1 "         No /etc/default/power file found - ERROR "
fi

 
if [ -f /etc/power.conf ] ; then 
        t_echo 0 "	 /etc/power.conf exists - FAILS second CHECK"
	else
        t_echo 1 "	 /etc/power.conf does not exists - PASSES CHECK"
fi

}

action=$1
	case ${action} in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	Fix
	;;
	-[Vv]*)
	Check
	;;
	 *)
        t_echo 1 " ERROR:Invalid arg $action"
        t_echo 1 " ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
        ;;
        esac

