:
# syslog.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0 Tue Oct 24 09:19:45 PDT 2000 added in check for "loghost"

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/syslog.conf'
OS=`uname -r`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

Intro() {

cat << EOF

 $MYNAME  - This program modifies /etc/syslog.conf so that console auth
  notice messages also get sent to the logfiles.

  Additionally checks to see if "loghost" is set in /etc/hosts. Titan recommends
  for all critical systems, that a remote system be set as "loghost" such that 
  system logs (auth logs at least) are stored both locally as well as remotely
  to a secured system. This is important since in most intrusions the local logfiles
  are often erased by the attacker.

EOF
}

Fix() {

 if [ -f /etc/syslog.conf ]; then
    t_echo 3 " File /etc/syslog.conf exists saving and continuing..."
    cp -p /etc/syslog.conf /etc/syslog.conf.ORIG.$DATE
   else
    t_echo 1 "       ERROR - File /etc/syslog.conf does not exist "
    exit 1
 fi


 if [ `awk '{print $1}' /etc/syslog.conf | grep "^#auth.notice"` ]; then
  t_echo 2 " Syslog auth notice messages disabled.. Fixing now..."
ed - /etc/syslog.conf << EOEF
g/#auth.notice/s/#auth.notice/auth.notice/
.
w
q
EOEF
  else
  t_echo 1 "       Syslog is auditing auth notices - PASSES CHECK"
  exit 1
fi

# send a KILL HUP signal to the syslog daemon so the change gets noticed

t_echo 2 " Telling Syslog to reset daemon and cache changes..."

PID=`cat /etc/syslog.pid`
kill -HUP $PID

}

Check() {

 if [ -f /etc/syslog.conf ]; then
   t_echo 3 " File /etc/syslog.conf exists checking contents...."
  else
   t_echo 1 "       ERROR - File /etc/syslog.conf does not exist exiting"
   exit 1
 fi

 if [ `awk '{print $1}' /etc/syslog.conf | grep "^#auth.notice"` ]; then
  t_echo 0 "        Syslog auth notice messages disabled - FAILS CHECK"
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (syslog.sh -f) Modify /etc/syslog.conf such that console"
        t_echo 3 "auth notice messages also get sent to the logfiles. "
        t_echo 3 " "    
        t_echo 3 "Additionally checks to see if "loghost" is set in /etc/hosts. Titan recommends"
        t_echo 3 "for all critical systems, that a remote system be set as "loghost" such that"
        t_echo 3 "system logs (auth logs at least) are stored both locally as well as remotely"
        t_echo 3 "to a secured system. This is important since in most intrusions the local"
        t_echo 3 "logfiles are often erased by the attacker."
        t_echo 3 " "
        t_echo 3 "======================================================================== "

 else
  t_echo 1 "        Syslog is auditing auth notices - PASSES CHECK"
 fi
 
}


loghost_check() {

 if [ -f /etc/inet/hosts ]; then
	LH=`grep "^[^#]*[ ]loghost"  /etc/inet/hosts`
	t_echo 3 " loghost currently set to $LH"
	if [ -z "$LH" ]; then
  	   t_echo 0 "   loghost is not defined in /etc/inet/hosts it is recommended that "
	   t_echo 0 "   you define loghost to be a remote system   - FAILS CHECK"
 else
	t_echo 0 "      loghost is defined in /etc/inet/hosts as:"
	t_echo 0 "      $LH  - PASSES CHECK"
	fi	
 fi

}

action=$1
case $action in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	  Fix
	  loghost_check
	 ;;
	 -[Vv]*)
	  Check
	  loghost_check
	 ;;
	 *)
 	 t_echo 1 " "
	 t_echo 1 "        ERROR:Invalid arg $action"
	 t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
 	 t_echo 1 " "
 	;;
esac
