:
# syslog_failed_login.sh
# version 4.0 Wed Jan 24 13:06:02 PST 2001

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/default/login'
OS=`uname -r`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh

Intro() {

cat << EOF
 $MYNAME - This program modifies /etc/default/login taking advantage of
 Solaris 8's SYSLOG_FAILED_LOGINS variable. Titan changes:
		From
	SYSLOG_FAILED_LOGINS=5 
		To
 	SYSLOG_FAILED_LOGINS=0 

If the variable is set to 0, login will log all failed login attempts.

EOF

}

Fix() {

 FAILED_LOGINS=`grep -s "^SYSLOG_FAILED_LOGINS=*" /etc/default/login |\
	sed 's/#.*//' | awk -F= '{print $2}'`

if [ "$FAILED_LOGINS" != "0" ]; then
  t_echo 2 "        System Failed Logins set incorrectly. Fixing "
ed - /etc/default/login << EOEF
g/^SYSLOG_FAILED_LOGINS/s//#\ SYSLOG_FAILED_LOGINS/g
.
w
a
# Titan version 4.0 change
.
w
a
SYSLOG_FAILED_LOGINS=0
.
w
q
EOEF
else
  t_echo 1 "         System Failed Logins set correctly. - PASSES CHECK" 
fi

}


Check() {

if [ -f /etc/default/login ]; then
 
 FAILED_LOGINS=`grep -s "^SYSLOG_FAILED_LOGINS=*" /etc/default/login |\
        sed 's/#.*//' | awk -F= '{print $2}'`
 
  if [ "$FAILED_LOGINS" -gt "0" ]; then

  t_echo 0 "        Failed Logins set to $FAILED_LOGINS - FAILS CHECK"
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (syslog_failed_logins.sh -f) Syslog should be configured"
        t_echo 3 "to log all failed login attempts. Modify /etc/default/login taking
advantage of"
        t_echo 3 "Solaris 8's SYSLOG_FAILED_LOGINS variable. Titan changes: "
        t_echo 3 "              From "
        t_echo 3 "      SYSLOG_FAILED_LOGINS=5  "
        t_echo 3 "              To "
        t_echo 3 "      SYSLOG_FAILED_LOGINS=0  "
        t_echo 3 " "
        t_echo 3 "If the variable is set to 0, login will log all failed login attempts. "   
        t_echo 3 " "
        t_echo 3 "======================================================================== "

  else
  t_echo 1 "        Failed logins is set to $FAILED_LOGINS - PASSES CHECK"
  fi
fi

}


action=$1
	case ${action} in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	Fix
	;;
	-[Vv]*)
	Check
	;;
	*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
	;;
	esac
#finis
