/* 
 * noshell - header file
 *
 *
 * Author:
 *		Michele D. Crabb
 *		Computer Sciences Corporation
 *		NASA Ames Research Center
 *		Mail Stop 258-6
 *		Moffett Field, CA 94035
 *		(415) 604 - 4337
 *		crabb@amelia.nas.nasa.gov
*/


#include <sys/types.h>
#include <sys/file.h>
#include <netdb.h>
#include <netinet/in.h>
#include <sys/socket.h>
#include <syslog.h>
#include <fcntl.h>
#include <stdio.h>
#include <utmp.h>

/* Degine the stuff that is different on every system */

#ifdef SUN
#define WTMP_FILE 	"/var/adm/wtmp"
#define MAILPROG 	"/usr/ucb/Mail"
#define NSLOOKUP	"/usr/etc/nslookup"
#define BSD_UTMP	1
#endif

#ifdef CONVEX
#define WTMP_FILE 	"/usr/adm/wtmp"
#define MAILPROG 	"/usr/ucb/Mail"
#define NSLOOKUP	"/usr/etc/nslookup"
#define BSD_UTMP	1
#endif

#ifdef BSD
#define WTMP_FILE 	"/usr/adm/wtmp"
#define MAILPROG 	"/usr/ucb/Mail"
#define NSLOOKUP	"/usr/local/bin/nslookup"
#define BSD_UTMP	1
#endif

#ifdef UTS
#define MAILPROG 	"/usr/bin/mailx"
#define NSLOOKUP	"/usr/bin/nslookup"
#endif

#ifdef CRAY
#define MAILPROG 	"/usr/bin/mailx"
#define NSLOOKUP	"/usr/ucb/nslookup"
#define BSD_UTMP	1
#endif

#ifdef SGI_IRIS
#define MAILPROG	"/usr/bin/Mail"
/* IRISes do not have nslookup */
#endif

#ifdef SGI_4D
#define MAILPROG	"/usr/sbin/Mail"
#define NSLOOKUP	"/usr/bsd/nslookup"
#endif


/* These items MUST be defined */
#define MAXLINE 	255
#define TMP_FILE 	"/usr/tmp/secmsg"
#define MBUFSIZE 	1024
#define DISABLED	"noshell"

/* Define SYSLOG if you want information logged to syslog.

   Define LOG_FACIL to be the name of the logging facility you
   want to use.  See man page on syslog() if you are unsure of
   what logging facilities are available.
*/
#define SYSLOG 1	/* */
#define LOG_FACIL	LOG_AUTH

/* Define INET_NTOA if the inet_ntoa function works on your systems
   type.  If you are not sure if the function works properly, compile
   and run the 'testntoa' program.  If the function does not work,
   then comment out the following line.
*/
#define INET_NTOA	inet_ntoa /* */

/* Define USE_MACRO if you inet_ntoa function is broken or if you prefere
   macro over inet_ntoa.
*/
/* #define USE_MACRO  1	/* */

#ifdef USE_MACRO
#	undef INET_NTOA
#endif

/* Define PRINT_MSG if you want to print a message to the screen for
   the user to see.  This may be the case for an account which has been
   disabled for some reason.

   Define USER_MSG to be the name of the file which contains the canned
   message for the user.
*/
#define PRINT_MSG 1		/* */
#define USER_MSG "%%USER_MSG%%"


/* Define MAIL_MSG if you want the syslog information mailed to a person.
   This would be appropriate on systems where the log files are not read
   on a regular basis.

   Define WATCHER to be the person who will receive the mail messages.
*/
#define MAIL_MSG 	1 	/* */
#define WATCHER 	"%%WATCHER%%"


/* Library Routines Used */
extern char *ctime();
extern char *getenv();
extern void exit();
extern long lseek();
extern void perror();

/* Macro to replace broken inet_ntoa function .  This macro takes an char *
   as a input arg and returns a char * to the internet address in "d.d.d.d"
   notation.
*/

#define str_ia(addrp)   sprintf("xxx.xxx.xxx.xxx", "%d.%d.%d.%d",addrp[0]&0xff, addrp[1]&0xff, addrp[2]&0xff,addrp[3]&0xff)




