/*
* Module:	noshell
*
* Summary:	log when someone successfully logs into a disabled account.
*		Send warning E-mail to root and/or print a message to user.
* Arguments:	none
*
* Notes:	SGI systems have a remote user and remote node environment
*		variables.  Non-sgi systems use the wtmp file to obtain
* 		the remote node name.  The file is opened and read from
*		back to front attempting to match the user name.
* Subroutines:
*		mail_msg() - Constructs and mails a message to root.
*		log_it()   - Logs a message via syslogd.
*		print_msg_to_screen() - Prints a message to the screen of user.
*		get_rmtaddr() - Get remote address by doing a 'nslookup'.
*
* Author:	Michele D. Crabb
*		Computer Sciences Corporation
*		NASA Ames Research Center
*		Mail Stop 258-6
*		Moffett Field, CA 94035
*		(415) 604 - 4337
*
* Date: 	April 15, 1990
*
* Modification History:
**************************************************************************/
#include "noshell.h"

/* Global Declarations */
void mail_msg();
void log_it();
void print_msg_to_screen();
char *get_rmtaddr();

char *login_id;		/* Name of the UID the person has logged in to. */
char *rmtnode;		/* Name of the remote host */
char *rmtuser;		/* Name of the remote user */
char *rmtaddr;		/* Address of the remote host */
char hostname[32];	/* Holder for the local hostname.  The gethostname
			   call wanted an array so thats why its an array.
			*/
int debug = 0;		/* For debugging only */


main()
{
	struct utmp myutmp;		/* structure of wtmp file */
	struct hostent *hostentry;	/* structure of host entry */
	int fd;				/* file descriptor for wtmp file */
	int trys=0;			/* counter for # of structs to read */
	u_short saveuid,savegid;	/* Holders for UID,GID */
	struct in_addr inaddr;
	u_long addr = 0;
	char *tmpname;			/* Temp string holder */
	char *cptr;			/* Just a temp char ptr */
	char *addrptr;			/* pointer to inet address */
	char tmpnode[15];		/* Temp array	*/
	int ii=0;			/* A dumb little counter */
	


/*  Try to get the login name from the environment variable */
if ( (tmpname = getenv("LOGNAME")) != '\0' )
	login_id = tmpname;
else
	if ( (tmpname = getenv("USER")) != '\0' )
		login_id = tmpname;
else
	login_id = "UNKNOWN LOCAL USER";


/* Try to get remote goodies if this is SYSV type system.
   Not all SYSV type systems use the REMOTE variables.  So
   far, only IRIS and SGI 4D systems use these that I know of.
 */
if ( (tmpname = getenv("REMOTEUSER")) != '\0')
	rmtuser = tmpname;
else
	rmtuser = "UNKNOWN REMOTE USER";

if ( (tmpname = getenv("REMOTEHOST")) != '\0')
	rmtnode = tmpname;
else
	rmtnode = '\0';   	/* Wait and see if we can get the remote host
				   information from the utmp entry. This will
				   only work for BSD-stlpe systems.
				*/

/* Get the hostname of local host */
(void)gethostname(hostname,sizeof(hostname));

/* Open the wtmp file and match on login_id */
if( (fd = open( WTMP_FILE, O_RDONLY )) == -1 )	
    (void) perror("Error opening utmp file");
if( lseek( fd, (long) (sizeof(myutmp)), 2 ) == -1 )	/* go 1 past eof of wtmp */
    (void) perror("lseek");

    do {

    /* Get the right utmp record.  First we backup two records. */
    if( lseek( fd, (long)(-2*(sizeof(myutmp))), 1 ) == -1 )
        (void) perror("lseek2");
    (void) read( fd,&myutmp,sizeof(myutmp) ); /* Read the goods */

    } while( strncmp(login_id,myutmp.ut_name,sizeof(myutmp.ut_name)) 
		&& trys++ < 100 );

#ifdef BSD_UTMP /* Remote host is available from UTMP structure on BSD-style systems */

	if (myutmp.ut_host[0]) {
    		myutmp.ut_host[15] = '\0';/* This needs to be null terminated
					   or garbage results on some systems.
					   */

		/* Because the utmp entry for the remote hostname is only
	   	16 chars on some systems, we only want to get the short
 	   	name.  Otherwise, the name my be truncated and the 
		gethostname call will fail.
        	*/
		while ( (myutmp.ut_host[ii] != '\56') && (ii < 16) ) {
			tmpnode[ii] = myutmp.ut_host[ii];
			ii++;	
		}
		tmpnode[ii] = '\0';
		rmtnode = tmpnode;
		if (debug) {
			printf("rmtnode is %s\n",rmtnode);
		}
	}
#endif

#ifdef UTS
	/* As usual, UTS does things a little differntly.  Since the 
	   remote host name is not part of the utmp stucture entry,
	   we work things backwards.  The Remote internet address _IS_ 
	   hidden in the ut_line field, at least on the NAS UTS system.
	*/
	inaddr.s_addr = addr  = *(u_long*)&myutmp.ut_line[8];
	addrptr = (char *)addr;
	if (addr && (hostentry = gethostbyaddr(&addr,sizeof(addr),
			AF_INET)) )
		rmtnode = hostentry->h_name;
#endif

/* This section is ugly, but I could not think of a better way to do things. */

if (rmtnode){
	/* Get the official host entry, if available */
#ifndef UTS
	if ( (hostentry = gethostbyname(rmtnode)) != NULL) {
		inaddr.s_addr = *(u_long *)hostentry->h_addr_list[0];
		addrptr = (char *)hostentry->h_addr_list[0];
	}

	if ( debug ) { /* print all host aliases */
		if (hostentry) {
			(void)printf("rmtnode is %s\n",rmtnode);
			while ( (cptr = *(hostentry->h_aliases)) != NULL) {
	         		(void) printf("\talias: %s\n", cptr);
	           		hostentry->h_aliases++;
	         	}
		}
		else
			(void) printf("Could not get hostentry\n");
    	}
#endif
	if (hostentry ) {
#ifdef INET_NTOA
		rmtaddr = (char *)inet_ntoa(inaddr);
#else
#ifdef USE_MACRO
	
		rmtaddr = (char *) str_ia(addrptr); 
#else
		rmtaddr = get_rmtaddr(rmtnode);  /* A last resort */
#endif
#endif
	}
	else  /* Unable to get hostentry, use orignal rmtnode 
		 and try to get info from Nameserver DB.
	      */
	/*	 rmtaddr = get_rmtaddr(rmtnode); */

	if ( !rmtaddr)	/* We still did not get the remote address */
		rmtaddr = "Remote Address Unknown";

}

else {		
		/* Don't know diddly */
		rmtnode = "Remote Host Unknown";
		rmtaddr = "Remote Address Unknown" ;
}

/* Send the mail message off.  But first, save the current uid and gid and
   then set the uid and gid to root.  After sending the mail message, set
   things back the way they were.  The UID and GID are reset  only for the 
   purpose of having the mail come from root as opposed to the login id
   of the account which was used.
*/
#ifdef MAIL_MSG
	saveuid = getuid(); savegid = getgid();
	(void) setuid(0); (void) setgid(0);
	(void)mail_msg(&myutmp);
	(void) setuid((int) saveuid); (void) setgid((int) savegid);
#endif

#ifdef SYSLOG 		/* Log information to Syslog */
	(void) log_it(&myutmp);
#endif

#ifdef PRINT_MSG  	/* Print a canned message to screen */
	(void) print_msg_to_screen();
#endif

/* Sleep log enough to allow user to read file */
(void) sleep(15);

} /* End of main */


/*
*	Subroutine Definitions
*/

/* mail message utils */
static char err_msg1[MBUFSIZE]="%s %s << xxEOFxx\n\
From: root\n\
To: %s\n\
Subject: WARNING - Login to disabled account\n\
\n\
************************ SECURITY ALERT ****************************\n\
\"%s\"  has attempted to log into \"%s\" \n\
using the login name of \"%s\"\n\
\n\
Time of login: %s\n\
The remote login originated from: %s\n\
\n\
Internet Address of remote host: %s\n\
\n\
Terminal line user attached to: %s.\n\
\n\
Please investigate this incident as soon as possible.\n\
xxEOFxx\n";

/******************************************************************************
* Subroutine  : mail_msg()
*
* Return Value: void
*
* Input Args  : 
*		struct utmp *myutmp
* Summary     : Constructs a mail messages using sprintf and mails the message
* 	        via a "command" call.
* Assumptions : None.
***************************************************************************** */
void mail_msg(myutmp)

struct utmp *myutmp;
{
	char buf[MBUFSIZE];		/* Buffer for mail message */
	char tmpholder[23];
	int notused = 0;		/* just to make sprint happy */


	/* This is needed as a workaround form the cray so rmtaddr
	   does not get squashed by the sprintf call. After call, rmtaddr
	   will be reset using tmpholder.
	*/
	strcpy(tmpholder,rmtaddr);

	/* Construct the mail message command  and fill in the blanks */
	notused = sprintf(buf,err_msg1,MAILPROG,WATCHER,WATCHER,rmtuser,
		hostname, login_id, ctime(&myutmp->ut_time),rmtnode,rmtaddr,
		myutmp->ut_line);
if (debug)
	printf("Mail msg: %s\n",buf);
	
else
	(void) system(buf); /* Send the message off */

	/* Reset the squashed rmtaddr pointer */
	rmtaddr = tmpholder;
}

/*****************************************************************************
* Subroutine   : log_it()
* Return Value : void
* Input Params : 
*		struct utmp *myutmp
* Summary      : Creates a syslog message using the sprintf call and logs the 
		 message using syslog.  
* Assumptions  : Syslog allows a buffer up to size 1024.
*		 LOG_FACIL is defined.
*******************************************************************************/
void log_it(myutmp)
struct utmp *myutmp;
{
	char buf1[256];
	char buf2[256];
	char tmpholder[23];
	int notused = 0;	/* to make sprintf happy on Crays */

	strcpy(tmpholder,rmtaddr);
	
	/* Construct the syslog message */
	 notused = sprintf(buf1,"WARNING: <%s@%s> attempted to log into the account <%s>" ,rmtuser,rmtnode,login_id);
	 notused =  sprintf(buf2,"The remote internet address was <%s> and the user attached to line <%s>.",tmpholder,myutmp->ut_line); 

#ifdef ULTRIX
	(void) openlog("noshell",LOG_PID);
#else
	(void) openlog("noshell",LOG_CONS,LOG_FACIL);
#endif

if (debug)
	printf("syslog: %s %s \n",buf1, buf2);
else
	(void) syslog(LOG_CRIT,"%s,%s",buf1,buf2);

} /* log_it */

/******************************************************************************
* Subroutine   : get_rmtaddr()
* Return Value : A character pointer to remote address.
* Input Params : 
*		 char *rmtnode - the name of the remote host name.
* Summary      : get_rmtaddr does a 'nslookup' and sends the output to a temp
*		 file. The temp file is then opened and read.  The only line
*		 we are interested is the forth line of information.
* Assumptions  : get_rmtaddr assumes that the output from nslookup is 5 lines
*		 of information and that the fourth line contains the remote
*		 internet address we are interested in.
*******************************************************************************/
char  *get_rmtaddr(rmthost)
char *rmthost;

{
	char command[128];
	FILE *fp;
	char line[MAXLINE];
	char junk[25];
	char tempaddr[16];		
	char *nslookup;
	int linenum=0;
	int notused = 0;	/* Just to make Cray sprintf happy */

#ifdef NSLOOKUP	/* This is needed since everyone does not have nslookup */
	nslookup = NSLOOKUP;

	/* Construct the command and do it. */
	notused = sprintf(command,"%s %s > %s",nslookup,rmthost,(char *)TMP_FILE);
	(void) system(command);

	/* Read the information in the temporary file.  We are only
 	   interested in the 5th line of information.
	*/
 	if ((fp = fopen(TMP_FILE, "r")) == NULL) {
                (void) fprintf(stderr,"noshell: could not open temp file %s\n",
			TMP_FILE);
                (void) fclose(fp);
                (void) exit(1);
        }
        else {
                while ( ( fgets(line,MAXLINE,fp) != NULL) && linenum < 5) {
			if (linenum == 4) {
				(void) sscanf(line,"%s %s",junk,tempaddr);
				tempaddr[15] = '\0';
				return(tempaddr);
			}
			linenum++;
           	}  
                (void) fclose(fp);
		(void) unlink(TMP_FILE);
        }
#else
	return("Can't get remote address");
#endif


} /* get_rmtaddr */

/******************************************************************************
* Subroutine   : print_msg_to_screen()
* Return Value : void.
* Input Params : None. 
* Summary      : print_msg_to_screen will open and read a pre-existing message
*		 file.  The contents of the file are printed to stdout.
*		 If the file open fails, only a short message is printed to
*		 stdout.
* Assumptions  : The file containing the message is <= 1024 characters which
*		 is the size of BUFSIZ on most Unix systems.
*******************************************************************************/
void print_msg_to_screen()
{
        FILE *fp;
        char buf[MBUFSIZE];

        fp=fopen(USER_MSG, "r");
        if (fp == NULL){
                (void) printf("What made you think this would work?\n");
                (void) exit(1);
        }
        while (fgets(buf, sizeof(buf),fp)) {
                (void) printf("%s",buf);
        }
        (void) fclose(fp);
}

